

===============
Memory Networks
===============

Papers
------

* [14.10] `Neural turing machines <http://arxiv.org/abs/1410.5401>`_
* [14.10] `Memory networks <http://arxiv.org/abs/1410.3916>`_
* [15.03] `End-to-end memory networks <https://arxiv.org/abs/1503.08895>`_
* [15.02] `Towards ai-complete question answering: A set of prerequisite toy tasks <http://arxiv.org/abs/1502.05698>`_
* [15.06] `Large-scale simple question answering with memory networks <http://arxiv.org/abs/1506.02075>`_
* [15.06] `Ask me anything: Dynamic memory networks for natural language processing <http://arxiv.org/abs/1506.07285>`_
* [15.11] `Evaluating prerequisite qualities for learning end-to-end dialog systems <http://arxiv.org/abs/1511.06931>`_
* [15.11] `The Goldilocks Principle: Reading Children's Books with Explicit Memory Representations <http://arxiv.org/abs/1511.02301>`_
* [16.03] `Dynamic memory networks for visual and textual question answering <https://arxiv.org/abs/1603.01417>`_
* [16.04] `Dialog-based Language Learning <http://arxiv.org/abs/1604.06045>`_
* [16.05] `Learning End-to-End Goal-Oriented Dialog <http://arxiv.org/abs/1605.07683>`_
* [16.05] `Hierarchical Memory Networks <https://arxiv.org/abs/1605.07427>`_
* [16.06] `Neural Machine Translation with External Phrase Memory <http://arxiv.org/abs/1606.01792>`_
* [16.06] `Memory-enhanced Decoder for Neural Machine Translation <http://arxiv.org/abs/1606.02003>`_
* [ICML2016] `Memory Networks for Language Understanding <http://www.thespermwhale.com/jaseweston/icml2016/>`_

Blogs
-----

* `Differentiable neural computers <https://deepmind.com/blog/differentiable-neural-computers/>`_
* `How to Code and Understand DeepMind's Neural Stack Machine <https://iamtrask.github.io/2016/02/25/deepminds-neural-stack-machine/>`_
